'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var styled = _interopDefault(require('styled-components'));

var findInnerComponentsKeys = function findInnerComponentsKeys(dataItem, config) {
  return Object.keys(dataItem).filter(function (key) {
    if (!config[key] || config[key].isParent) return false;
    var dataItemProperty = dataItem[key];

    if (dataItemProperty) {
      var component = isRichDataObject(dataItemProperty) ? dataItemProperty.component : config[key].component;
      return Boolean(component);
    }

    return false;
  });
};

var findTooltipKeys = function findTooltipKeys(dataItem, config) {
  return Object.keys(dataItem).filter(function (key) {
    var dataItemProperty = dataItem[key];

    if (typeof dataItemProperty !== 'undefined') {
      var isTooltipKey = config[key] && (config[key].tooltip || config[key].label);
      return Boolean(isTooltipKey);
    }

    return false;
  });
};

var ILegend;

(function (ILegend) {
  ILegend["empty"] = "empty";
  ILegend["isParent"] = "isParent";
  ILegend["isFilled"] = "isFilled";
})(ILegend || (ILegend = {}));

var findStackedYAxisMax = function findStackedYAxisMax(config, data) {
  var parentBar = Object.entries(config).find(function (configItem) {
    return configItem[1][ILegend.isParent];
  });

  if (!parentBar || !parentBar[0]) {
    throw new Error('Stacked bar chart must have a parent bar.');
  }

  var parentBarKey = parentBar[0];
  var maxYAxis = Math.max.apply(Math, data.map(function (dataItem) {
    var dataItemProperty = dataItem[parentBarKey];
    if (typeof dataItemProperty === 'undefined') return 0;
    return isRichDataObject(dataItemProperty) ? Number(dataItemProperty.value) : Number(dataItemProperty);
  }));
  return maxYAxis;
};

var useResize = function useResize(callback) {
  var handleResize = React.useMemo(function () {
    return function (event) {
      return callback(event);
    };
  }, [callback]);
  window.addEventListener('resize', handleResize, false);
};

var isRichDataObject = function isRichDataObject(dataItem) {
  return dataItem.component !== undefined || dataItem.value !== undefined;
};

var isNumber = function isNumber(val) {
  return typeof val === 'boolean';
};

var buildPath = function buildPath(key, config, d) {
  if (config[key]) {
    var component = config[key].component || React.createElement(Path, null);
    return React.createElement(React.Fragment, {
      key: key
    }, React.cloneElement(component, {
      d: d
    }));
  }
};

var buildPathD = function buildPathD(dataKey, dataSlice, config, SVGHeight, SVGWidth, cellsNumber, yAxisMax, yAxisMin, flexure) {
  return dataSlice.reduce(function (acum, item, i) {
    var calcY = function calcY(val) {
      return SVGHeight - SVGHeight / (yAxisMax - yAxisMin) * (val - yAxisMin);
    };

    var prevItem = dataSlice[i - 1] || 0,
        prevIndex = i > 1 ? i - 1 : 0,
        prevY = calcY(prevItem),
        prevX = SVGWidth / (cellsNumber - 1) * prevIndex;
    var x = SVGWidth / (cellsNumber - 1) * i,
        y = calcY(item);
    var resultingFlexure = config[dataKey] && config[dataKey].flexure || flexure;

    if (Number(resultingFlexure) >= 0 || Number(resultingFlexure) <= 100) {
      resultingFlexure = Number(resultingFlexure);
    } else {
      throw new Error('Flexure must be between 0 and 100');
    }

    var reservedStrokeWidth = 100;
    var deltaPull = 100,
        deltaSmall = resultingFlexure,
        deltaLarge = 100 - resultingFlexure;
    var delta = (x - prevX) / deltaPull;
    var ponintsSlice = i === 0 ? "m " + x + " " + y + " " : "c " + delta * deltaSmall + " 0 " + delta * deltaLarge + " " + (y - prevY) + " " + (x - prevX) + " " + (y - prevY) + " ";
    var lastSlice = i === dataSlice.length - 1 ? // We build the full chart is isFilled flag is provided
    "c " + delta * deltaSmall + " 0 " + delta * deltaLarge + " " + (y - prevY) + " " + (x - prevX) + " " + (y - prevY) + " H " + (x + reservedStrokeWidth) + " V " + (SVGHeight + reservedStrokeWidth) + " H 0" : undefined;
    return acum += lastSlice || ponintsSlice;
  }, '');
};

var getBarHeight = function getBarHeight(barValue, maxYAxis, minYAxis) {
  return Number(barValue - minYAxis) * 100 / (maxYAxis - minYAxis);
};

var getInnerBarHeight = function getInnerBarHeight(barValue, maxYValue, minYValue) {
  if (minYValue === void 0) {
    minYValue = 0;
  }

  return (Number(barValue) - minYValue) * 100 / (maxYValue - minYValue) + "%";
};

var buildTooltip = function buildTooltip(tooltipData, barsNum, maxYAxis, minYAxis, tooltipIsOpen, tooltip, config, isBarChart) {
  var _tooltip$isSmartToolt = tooltip.isSmartTooltipPositioning,
      isSmartTooltipPositioning = _tooltip$isSmartToolt === void 0 ? true : _tooltip$isSmartToolt,
      hints = tooltip.hints;
  var tooltipValues = tooltipData.tooltipValues;
  var parentKey = findParentBar(config);

  if (parentKey && isBarChart) {
    tooltipValues = [].concat(tooltipData.tooltipValues.filter(function (item) {
      return item.key !== parentKey;
    }));
  }

  var parentItem = parentKey && isBarChart ? tooltipData.tooltipValues.find(function (item) {
    return item.key === parentKey;
  }) : undefined;

  var getDenotation = function getDenotation(key) {
    return config[key] && config[key].denoteAs ? config[key].denoteAs : '';
  };

  var children = React.createElement(React.Fragment, null, React.createElement(TooltipList, null, parentItem && React.createElement(TooltipListItem, null, React.createElement(TooltipParentItem, null, React.createElement(TooltipLabel, null, parentItem.label), React.createElement(TooltipValue, null, !isRichDataObject(parentItem.value) ? "" + parentItem.value + getDenotation(parentItem.key) : "" + parentItem.value.value + getDenotation(parentItem.key)))), tooltipValues.map(function (tooltipItemData) {
    var denoteAs = getDenotation(tooltipItemData.key);
    return React.createElement(React.Fragment, {
      key: tooltipItemData.key
    }, React.createElement(TooltipListItem, null, hints && hints[tooltipItemData.key], React.createElement(TooltipListItemTextContent, null, React.createElement(TooltipLabel, null, tooltipItemData.label), React.createElement(TooltipValue, null, !isRichDataObject(tooltipItemData.value) ? "" + tooltipItemData.value + denoteAs : "" + tooltipItemData.value.value + denoteAs))));
  })), React.createElement(TooltipXAxisValue, null, tooltipData.xAxisValue));
  var component = tooltip.component || React.createElement(TooltipWrapper, null);
  var bottom = getBarHeight(Number(tooltipData.barValue), maxYAxis, minYAxis);
  var barNumAdjustment = isBarChart ? 0 : -1;
  var singleBarPersentage = 100 / (barsNum + barNumAdjustment);
  var barsPersentageAdjustment = isBarChart ? singleBarPersentage : 0;
  var defaultLeft = isSmartTooltipPositioning ? singleBarPersentage * tooltipData.barIndex : 100 / barsNum * tooltipData.barIndex + 100 / barsNum / 2;

  var _buildTooltipTransfor = buildTooltipTransform(defaultLeft, bottom, singleBarPersentage, barsPersentageAdjustment, Boolean(isBarChart), isSmartTooltipPositioning),
      left = _buildTooltipTransfor.left,
      translateX = _buildTooltipTransfor.translateX,
      translateY = _buildTooltipTransfor.translateY,
      xOffset = _buildTooltipTransfor.xOffset,
      yOffset = _buildTooltipTransfor.yOffset;

  var floatingBottom = bottom < 0 ? 0 : bottom > 100 ? 100 : bottom;
  var floatingTranslateY = floatingBottom === 100 ? 100 : translateY;
  var transform = "\n    translateX(calc(" + translateX + "% + " + xOffset + "px)) translateY(calc(" + floatingTranslateY + "% + " + yOffset + "px))\n  ";
  var componentProps = {
    style: {
      left: left + "%",
      transform: transform,
      bottom: floatingBottom + "%"
    },
    children: children
  };

  if (!tooltipIsOpen) {
    componentProps.style.opacity = 0;
  }

  return React.cloneElement(component, componentProps);
};

var removeExtraValues = function removeExtraValues(data, cellsNum) {
  return data.slice(data.length - cellsNum, data.length);
};

var fillMissingValues = function fillMissingValues(data, cellsNum, maxY) {
  var missingArr = Array.from({
    length: cellsNum - data.length
  }, function () {
    return {
      empty: maxY
    };
  });
  return [].concat(data, missingArr);
};

var findBarsYAxisMax = function findBarsYAxisMax(config, data) {
  var max = data.reduce(function (acum, dataItem) {
    Object.keys(dataItem).filter(function (key) {
      if (!config[key]) return acum;
      var dataItemProperty = dataItem[key];
      var value = isRichDataObject(dataItemProperty) ? dataItemProperty.value : dataItemProperty;
      if (acum < value) acum = Number(value);
    });
    return acum;
  }, 0);
  return max;
};

var ID = function ID() {
  return (// Math.random should be unique because of its seeding algorithm.
    // Convert it to base 36 (numbers + letters), and grab the first 9 characters
    // after the decimal.
    '_' + Math.random().toString(36).substr(2, 9)
  );
};

var getYAxisValues = function getYAxisValues(yAxisTicksNum, maxValue, minValue) {
  return Array.from({
    length: yAxisTicksNum
  }, function (_, i) {
    var yAxisStep = (maxValue - minValue) / (yAxisTicksNum - 1);
    if (!i) return minValue;
    if (i === yAxisTicksNum - 1) return maxValue;
    return Math.round(yAxisStep * i + minValue);
  }).reverse();
};

var buildTooltipTransform = function buildTooltipTransform(left, bottom, singleBarPersentage, barsPersentageAdjustment, isBarChart, isSmartTooltipPositioning) {
  if (!isSmartTooltipPositioning) {
    return {
      left: left,
      translateX: -50,
      translateY: 0,
      xOffset: 0,
      yOffset: -8
    };
  }

  var isRightSide = left >= 50,
      mdOffset = 8,
      smOffset = 4;
  var translateX = 0,
      xOffset = 12,
      translateY = 30,
      yOffset = 0;

  if (isRightSide) {
    translateX = -100;
    xOffset = isBarChart ? 12 : -12;
    left += barsPersentageAdjustment;
  } // there are some diff on the width calc for bars and lines


  if (!isBarChart) {
    // if we have small values, let's show it above the lines
    if (bottom < 33) {
      translateY = 0;
      yOffset = -mdOffset;
      xOffset = isRightSide ? mdOffset : -mdOffset; // let it adapt to the bottom value
    } else if (bottom > 50) {
      translateY = bottom;
    }
  } else {
    isRightSide ? left -= singleBarPersentage : left += singleBarPersentage;
    translateY = bottom;
    yOffset = 0;
    xOffset = isRightSide ? -smOffset : smOffset;
  }

  return {
    left: left,
    translateX: translateX,
    translateY: translateY,
    xOffset: xOffset,
    yOffset: yOffset
  };
};

var fillDataRelativeToXAxis = function fillDataRelativeToXAxis(data, xAxisTicksNum) {
  var dataWithUniqueIDs = [].concat(data);
  if (xAxisTicksNum > data.length) dataWithUniqueIDs = fillMissingValues(dataWithUniqueIDs, xAxisTicksNum, 100);else if (xAxisTicksNum < data.length) dataWithUniqueIDs = removeExtraValues(dataWithUniqueIDs, xAxisTicksNum);
  dataWithUniqueIDs = dataWithUniqueIDs.map(function (dataItem) {
    return !dataItem.dataItemUID ? Object.assign(dataItem, {
      dataItemUID: ID()
    }) : dataItem;
  });
  return dataWithUniqueIDs;
};

var findParentBar = function findParentBar(config) {
  return Object.entries(config).map(function (arr) {
    return arr[1].isParent ? arr[0] : null;
  }).find(function (key) {
    return key && key;
  });
};

var checkIfAllBarsHaveKeyOrEmpty = function checkIfAllBarsHaveKeyOrEmpty(data, key) {
  var checkedData = data.filter(function (dataItem) {
    return dataItem[key] || dataItem[ILegend.empty];
  });
  return checkedData.length === data.length;
};

var fillStackedBarChartWithParents = function fillStackedBarChartWithParents(data, key) {
  return [].concat(data).map(function (dataItem) {
    var _Object$assign;

    return !(key in dataItem) ? Object.assign({}, dataItem, (_Object$assign = {}, _Object$assign[key] = 0, _Object$assign)) : dataItem;
  });
};

var getDenotedHeight = function getDenotedHeight(height) {
  return typeof height === 'number' ? height + "px" : height.includes('px') || height.includes('%') || height.includes('rem') || height.includes('em') || height.includes('vh') ? height : height + "px";
};

/**
 * @example {
 *    x: [1, 2, 3],
 *    y: [2, 0, 1],
 * }
 */

var buildDataSlices = function buildDataSlices(uiniqueKeysData, config) {
  var keys = uiniqueKeysData.map(function (item) {
    return findInnerComponentsKeys(item, config);
  });
  /**
   * @example {
   *    [x, y]
   * }
   */

  var uniqueKeys = keys.reduce(function (acum, item) {
    var uniqueIterationKeys = item.filter(function (key) {
      return acum.indexOf(key) === -1;
    });
    return [].concat(acum, uniqueIterationKeys);
  }, []);
  /**
   * @example {
   *    x: [1, 2, 3],
   *    y: [2, 0, 1],
   * }
   */

  var dataSlices = uiniqueKeysData.reduce(function (acum, dataItem) {
    uniqueKeys.forEach(function (key) {
      if (!acum[key]) acum[key] = [];
      var dataItemProperty = dataItem[key];

      if (typeof dataItemProperty !== 'undefined') {
        var value = isRichDataObject(dataItemProperty) ? Number(dataItemProperty.value) : Number(dataItemProperty);
        acum[key].push(value);
      }
    });
    return acum;
  }, {});
  return dataSlices;
};

var buildGrid = function buildGrid(xTicks, xAxisGrid, yAxisValues, yAxisGrid, isBarChart) {
  var yComponent = yAxisGrid && isNumber(yAxisGrid) ? React.createElement(YGrid, null) : yAxisGrid;
  var xComponent = xAxisGrid && isNumber(xAxisGrid) ? React.createElement(XGrid, null) : xAxisGrid;
  var xMap = Array.from(Array(isBarChart ? xTicks.length + 1 : xTicks.length).keys());
  var singleItemWidth = 100 / (isBarChart ? xTicks.length : xTicks.length - 1);
  return React.createElement(React.Fragment, null, yComponent && xMap.map(function (_, index) {
    return React.createElement(React.Fragment, {
      key: index
    }, React.cloneElement(yComponent, {
      style: {
        left: "calc(" + index * singleItemWidth + "%)"
      }
    }));
  }), xComponent && yAxisValues.map(function (_, index) {
    return React.createElement(React.Fragment, {
      key: index
    }, React.cloneElement(xComponent, {
      style: {
        bottom: index * 100 / (yAxisValues.length - 1) + "%"
      }
    }));
  }));
};

var buildXAxis = function buildXAxis(xAxis, data, step, isLineChart) {
  var children = data.map(function (item, index) {
    return buildXAxisItem(xAxis, step, index, item, data.length, isLineChart, item[xAxis.key]);
  });
  return xAxis.sectionComponent ? React.cloneElement(xAxis.sectionComponent, {
    children: children
  }) : isLineChart ? React.createElement(XAxisLineWrapper, null, children) : React.createElement(XAxisBarWrapper, null, children);
};
var buildXAxisItem = function buildXAxisItem(xAxis, step, index, dataItem, itemsNum, isLineChart, children) {
  var stepCoef = Math.floor(itemsNum / step) - 1;
  var removeAllAfter = Math.floor(stepCoef * step);
  var singleItemWidth = isLineChart ? 100 / (itemsNum - 1) : 100 / itemsNum;
  return React.createElement(React.Fragment, {
    key: dataItem.dataItemUID
  }, (index % step || index > removeAllAfter) && index !== itemsNum - 1 ? undefined : React.cloneElement(xAxis.component || React.createElement(XAxisItem, {
    key: index
  }), {
    children: children,
    style: {
      left: index * singleItemWidth + "%",
      width: isLineChart ? 'auto' : singleItemWidth + "%"
    }
  }));
};

var buildYAxisItems = function buildYAxisItems(yAxis, index, val) {
  var value = yAxis.formatFn ? yAxis.formatFn(val) : val;
  var resultingValue = "" + value + (yAxis.denoteAs ? yAxis.denoteAs : '');
  return yAxis.component ? React.createElement(React.Fragment, {
    key: index
  }, React.cloneElement(yAxis.component, {
    children: resultingValue
  })) : React.createElement(YAxisItem, {
    key: index
  }, resultingValue);
};
var buildYAxis = function buildYAxis(yAxis, data) {
  var children = data.map(function (item, index) {
    return buildYAxisItems(yAxis, index, item);
  });
  return yAxis.sectionComponent ? React.cloneElement(yAxis.sectionComponent, {
    children: children
  }) : React.createElement(YAxisWrapper, null, children);
};

var ParentBar = function ParentBar(props) {
  var dataConfigKey = props.dataConfigKey,
      dataItemProp = props.dataItemProp,
      config = props.config,
      barsNum = props.barsNum,
      maxYAxis = props.maxYAxis,
      minYAxis = props.minYAxis,
      setTooltipData = props.setTooltipData,
      toggleTooltip = props.toggleTooltip,
      children = props.children,
      tooltipData = props.tooltipData,
      setSelectionInterval = props.setSelectionInterval,
      selectionInterval = props.selectionInterval,
      withSelection = props.withSelection,
      selectionHighlighter = props.selectionHighlighter,
      index = props.index,
      applyBarSelection = props.applyBarSelection,
      clearLocalSelection = props.clearLocalSelection,
      selectionArray = props.selectionArray,
      getSelectionMinMax = props.getSelectionMinMax,
      setSelectionArray = props.setSelectionArray;
  var component = dataConfigKey === ILegend.empty ? config[dataConfigKey] && config[dataConfigKey].component || React.createElement(EmptyBar, null) : isRichDataObject(dataItemProp) ? dataItemProp.component(children) // we take the compoent right from the data item
  : config[dataConfigKey] && config[dataConfigKey].component || // we take the component from the config
  React.createElement(BarGroup, null); // or we take the default one

  var value = isRichDataObject(dataItemProp) ? dataItemProp.value : dataItemProp;
  var barHeight = getBarHeight(Number(value), maxYAxis, minYAxis);
  var selectedByInterval = Boolean((selectionInterval == null ? void 0 : selectionInterval.length) && selectionInterval[0] <= index && selectionInterval[1] >= index);
  var selectedNow = Boolean((selectionArray == null ? void 0 : selectionArray.length) && selectionArray[0] <= index && selectionArray[1] >= index);
  var componentProps = {
    style: {
      height: (barHeight > 100 ? 100 : barHeight) + "%",
      width: 100 + "%"
    },
    selected: selectedByInterval
  };
  if (!isRichDataObject(dataItemProp)) componentProps.children = children;

  var handlePointerDown = function handlePointerDown(id) {
    if (!selectionArray.length) setSelectionArray([id]);
  };

  var handlePointerUp = function handlePointerUp() {
    var _getSelectionMinMax = getSelectionMinMax(),
        min = _getSelectionMinMax[0],
        max = _getSelectionMinMax[1];

    if (selectionArray.length) {
      setSelectionInterval([min, max].sort(function (a, b) {
        return a - b;
      }));
    }

    clearLocalSelection();
  };

  var handlePointerOver = function handlePointerOver(id) {
    var selectedIds = [].concat(selectionArray);
    var min = Math.min.apply(Math, selectionArray);
    var max = Math.max.apply(Math, selectionArray);

    if (selectionArray.length) {
      if (id > max) {
        selectedIds = [min, id];
      } else if (id < min) {
        selectedIds = [id, max];
      }

      setSelectionArray(selectedIds);
    }
  };

  return React.createElement(InvisibleBarGroupWrapper, {
    onClick: applyBarSelection ? function () {
      return applyBarSelection(index);
    } : undefined,
    isSelecting: Boolean(selectionArray.length),
    withSelection: withSelection,
    selectionHighlighter: selectionHighlighter,
    onPointerUp: withSelection ? function () {
      return handlePointerUp();
    } : undefined,
    onPointerDown: withSelection ? function () {
      return handlePointerDown(index);
    } : undefined,
    onPointerOver: withSelection ? function () {
      return handlePointerOver(index);
    } : undefined,
    selected: selectedNow,
    selectedByInterval: selectedByInterval,
    width: 100 / barsNum + "%",
    onMouseEnter: function onMouseEnter() {
      tooltipData && dataConfigKey !== ILegend.empty && setTooltipData(tooltipData);
      toggleTooltip(true);
    }
  }, React.cloneElement(component, componentProps));
};

var BasicBar = function BasicBar(_ref) {
  var dataConfigKey = _ref.dataConfigKey,
      dataItem = _ref.dataItem,
      dataItemProp = _ref.dataItemProp,
      config = _ref.config,
      innerSum = _ref.innerSum,
      minYValue = _ref.minYValue;
  var component = isRichDataObject(dataItemProp) ? dataItemProp.component() // we take the compoent right from the data item
  : config[dataConfigKey].component || React.createElement(BarGroup, null); // we take the component from the config // or we take the default one

  var value = isRichDataObject(dataItemProp) ? dataItemProp.value : dataItemProp;
  var componentProps = {
    style: {
      height: getInnerBarHeight(Number(value), innerSum, minYValue)
    }
  };
  return React.createElement(React.Fragment, {
    key: "inner_" + dataItem.dataItemUID + "_" + dataConfigKey
  }, React.cloneElement(component, componentProps));
};

var isParentBar = function isParentBar(dataConfigKey, config) {
  return config[dataConfigKey] && config[dataConfigKey].isParent || dataConfigKey === ILegend.empty;
};

var getDataItemValue = function getDataItemValue(dataItem) {
  return isRichDataObject(dataItem) ? dataItem.value : dataItem;
};

var BarChartBars = function BarChartBars(_ref) {
  var uiniqueKeysData = _ref.uiniqueKeysData,
      config = _ref.config,
      xAxisValues = _ref.xAxisValues,
      minValue = _ref.minValue,
      maxValue = _ref.maxValue,
      tooltip = _ref.tooltip,
      selection = _ref.selection;

  var _React$useState = React.useState(null),
      tooltipData = _React$useState[0],
      setTooltipData = _React$useState[1];

  var _React$useState2 = React.useState([]),
      selectionArray = _React$useState2[0],
      setSelectionArray = _React$useState2[1];

  var _React$useState3 = React.useState(false),
      tooltipIsOpen = _React$useState3[0],
      toggleTooltip = _React$useState3[1];

  var isStackedBarChart = Object.entries(config).map(function (item) {
    return item[1];
  }).some(function (item) {
    return item.isParent;
  });
  var selectionInterval = (selection == null ? void 0 : selection.selectionInterval) || [];

  var setSelectionInterval = (selection == null ? void 0 : selection.setSelectionInterval) || function () {};

  var selectionHighlighter = selection == null ? void 0 : selection.selectionHighlighter;

  var applyBarSelection = function applyBarSelection(id) {
    var selectedBarsLengthMap = {
      0: function _() {
        return setSelectionInterval([id]);
      },
      1: function _() {
        return setSelectionInterval([].concat(selectionInterval, [id]).sort(function (a, b) {
          return a - b;
        }));
      },
      2: function _() {
        return setSelectionInterval([id]);
      }
    }; // @ts-ignore

    selectedBarsLengthMap[selectedBars.length]();
  };

  var handlePointerLeave = function handlePointerLeave() {
    if (!selection) return;

    var _getSelectionMinMax = getSelectionMinMax(),
        min = _getSelectionMinMax[0],
        max = _getSelectionMinMax[1];

    if (selectionArray.length > 1) {
      setSelectionInterval([min, max]);
      clearLocalSelection();
    }
  };

  var getSelectionMinMax = function getSelectionMinMax() {
    var min = Math.min.apply(Math, selectionArray);
    var max = Math.max.apply(Math, selectionArray);
    return [min, max];
  };

  var clearLocalSelection = function clearLocalSelection() {
    setSelectionArray([]);
  };

  var withSelection = Boolean(selection);
  return React.createElement(BarChartBarsWrapper, {
    onPointerLeave: function onPointerLeave() {
      return selection ? handlePointerLeave() : undefined;
    },
    onMouseLeave: function onMouseLeave() {
      toggleTooltip(false);
      setTooltipData(null);
    }
  }, React.useMemo(function () {
    return uiniqueKeysData.map(function (dataItem, index) {
      var innerBarsKeys = findInnerComponentsKeys(dataItem, config);
      var tooltipKeys = findTooltipKeys(dataItem, config);
      var tooltipValues = tooltipKeys.reduce(function (acum, key) {
        var tooltipItemValues = {
          label: config[key].label,
          key: key,
          value: dataItem[key]
        };
        acum.push(tooltipItemValues);
        return acum;
      }, []);
      var innerBarsSum = innerBarsKeys.reduce(function (acum, key) {
        var dataItemProperty = dataItem[key];
        var value = isRichDataObject(dataItemProperty) ? Number(dataItemProperty.value) : Number(dataItemProperty);
        return acum + value;
      }, 0);
      var children = Object.keys(dataItem).map(function (dataConfigKey) {
        if (config[dataConfigKey] && !config[dataConfigKey].isParent) {
          return React.createElement(BasicBar, {
            key: "inner_" + dataItem.dataItemUID + "_" + dataConfigKey,
            dataConfigKey: dataConfigKey,
            dataItem: dataItem,
            dataItemProp: dataItem[dataConfigKey],
            config: config,
            innerSum: innerBarsSum,
            minYValue: minValue
          });
        }
      });
      return Object.keys(dataItem).map(function (dataConfigKey) {
        if (isParentBar(dataConfigKey, config) || !isStackedBarChart && config[dataConfigKey] && config[dataConfigKey].component) {
          return React.createElement(ParentBar, {
            withSelection: withSelection,
            selectionHighlighter: selectionHighlighter,
            getSelectionMinMax: getSelectionMinMax,
            clearLocalSelection: clearLocalSelection,
            selectionArray: selectionArray,
            applyBarSelection: withSelection ? applyBarSelection : undefined,
            setSelectionArray: setSelectionArray,
            selectionInterval: selectionInterval,
            setSelectionInterval: setSelectionInterval,
            index: index,
            uID: dataItem.dataItemUID,
            key: "invisible_" + dataItem.dataItemUID + "_" + dataConfigKey,
            dataConfigKey: dataConfigKey,
            dataItemProp: dataItem[dataConfigKey],
            config: config,
            barsNum: uiniqueKeysData.length,
            maxYAxis: maxValue,
            minYAxis: minValue,
            setTooltipData: setTooltipData,
            toggleTooltip: toggleTooltip,
            tooltipData: {
              xAxisValue: xAxisValues[index],
              dataConfigKey: dataConfigKey,
              tooltipValues: tooltipValues,
              barIndex: index,
              barValue: Number(getDataItemValue(dataItem[dataConfigKey]))
            }
          }, children);
        }
      });
    });
  }, [uiniqueKeysData, minValue, maxValue, selectionArray, selection]), tooltip && tooltip.isVisible && tooltipData && buildTooltip(tooltipData, uiniqueKeysData.length, maxValue, minValue, tooltipIsOpen, tooltip, config, 'isBarChart'));
};

var BarChart = function BarChart(_ref) {
  var height = _ref.height,
      data = _ref.data,
      config = _ref.config,
      yAxis = _ref.yAxis,
      xAxis = _ref.xAxis,
      tooltip = _ref.tooltip,
      selection = _ref.selection;
  var isStackedBarChart = Object.entries(config).map(function (item) {
    return item[1];
  }).some(function (item) {
    return item.isParent;
  });
  var _xAxis$step = xAxis.step,
      xAxisStep = _xAxis$step === void 0 ? Math.round(data.length > 10 ? data.length / 4 : 1) : _xAxis$step,
      _xAxis$ticksNum = xAxis.ticksNum,
      xAxisTicksNum = _xAxis$ticksNum === void 0 ? data.length : _xAxis$ticksNum,
      xAxisKey = xAxis.key,
      xAxisGrid = xAxis.grid;
  var uiniqueKeysData = fillDataRelativeToXAxis(data, xAxisTicksNum);
  var parentBar = findParentBar(config);

  if (parentBar && !checkIfAllBarsHaveKeyOrEmpty(uiniqueKeysData, parentBar)) {
    uiniqueKeysData = fillStackedBarChartWithParents(uiniqueKeysData, parentBar);
  }

  var _yAxis$maxValue = yAxis.maxValue,
      maxValue = _yAxis$maxValue === void 0 ? isStackedBarChart ? findStackedYAxisMax(config, uiniqueKeysData) : findBarsYAxisMax(config, uiniqueKeysData) : _yAxis$maxValue,
      _yAxis$minValue = yAxis.minValue,
      minValue = _yAxis$minValue === void 0 ? 0 : _yAxis$minValue,
      _yAxis$ticksNum = yAxis.ticksNum,
      yAxisTicksNum = _yAxis$ticksNum === void 0 ? 3 : _yAxis$ticksNum,
      yAxisGrid = yAxis.grid;
  var xAxisValues = data.map(function (dataItem) {
    return dataItem[xAxisKey];
  });
  var yAxisValues = getYAxisValues(yAxisTicksNum, maxValue, minValue);
  return React.createElement(ChartWrapper, {
    height: height && getDenotedHeight(height)
  }, buildYAxis(yAxis, yAxisValues), React.createElement(ChartWithXAxisWrapper, null, React.createElement(ChartVisualsWrapper, null, buildGrid(xAxisValues, xAxisGrid, yAxisValues, yAxisGrid, 'isBarChart'), React.createElement(BarChartBars, {
    uiniqueKeysData: uiniqueKeysData,
    config: config,
    selection: selection,
    xAxisValues: xAxisValues,
    minValue: minValue,
    maxValue: maxValue,
    tooltip: tooltip
  })), buildXAxis(xAxis, uiniqueKeysData, xAxisStep)));
};

var BasicInvisibleBar = function BasicInvisibleBar(_ref) {
  var dataConfigKey = _ref.dataConfigKey,
      dataItemProp = _ref.dataItemProp,
      config = _ref.config,
      innerSum = _ref.innerSum,
      minYValue = _ref.minYValue,
      tooltip = _ref.tooltip;

  if (config[dataConfigKey]) {
    var point = tooltip && tooltip.hints && tooltip.hints[dataConfigKey] || React.createElement(HintPoint, null);
    if (!dataItemProp) return React.createElement(React.Fragment, null);
    var component = isRichDataObject(dataItemProp) ? React.createElement(InvisibleBar, null, point, dataItemProp.component()) : React.createElement(InvisibleBar, null, point);
    var value = isRichDataObject(dataItemProp) ? dataItemProp.value : dataItemProp;
    var componentProps = {
      style: {
        height: getInnerBarHeight(Number(value), innerSum, minYValue)
      }
    };
    return React.createElement(React.Fragment, null, React.cloneElement(component, componentProps));
  }

  return React.createElement(React.Fragment, null);
};

var ParentInvisibleBar = function ParentInvisibleBar(_ref) {
  var max = _ref.max,
      barsNum = _ref.barsNum,
      maxYAxis = _ref.maxYAxis,
      minYAxis = _ref.minYAxis,
      setTooltipData = _ref.setTooltipData,
      toggleTooltip = _ref.toggleTooltip,
      tooltipData = _ref.tooltipData,
      children = _ref.children;
  var component = React.createElement(InvisibleBarGroup, null, children);
  var height = getBarHeight(max, maxYAxis, minYAxis);
  var componentProps = {
    onMouseEnter: function onMouseEnter() {
      tooltipData && setTooltipData(tooltipData);
      toggleTooltip(true);
    },
    style: {
      height: (height || 30) + "%"
    }
  };
  return React.createElement(InvisibleBarGroupWrapper, {
    width: 100 / barsNum + "%",
    onMouseEnter: function onMouseEnter() {
      tooltipData && tooltipData.xAxisValue && setTooltipData(tooltipData);
      toggleTooltip(true);
    }
  }, React.cloneElement(component, componentProps));
};

var ParentInvisibleBar$1 = /*#__PURE__*/React.memo(ParentInvisibleBar);

var LineChartBarsOverlay = function LineChartBarsOverlay(_ref) {
  var uiniqueKeysData = _ref.uiniqueKeysData,
      config = _ref.config,
      valuesArrays = _ref.valuesArrays,
      tooltip = _ref.tooltip,
      xAxisValues = _ref.xAxisValues,
      maxValue = _ref.maxValue,
      minValue = _ref.minValue;

  var _React$useState = React.useState(null),
      tooltipData = _React$useState[0],
      setTooltipData = _React$useState[1];

  var _React$useState2 = React.useState(false),
      tooltipIsOpen = _React$useState2[0],
      toggleTooltip = _React$useState2[1];

  return React.createElement(React.Fragment, null, React.createElement(InvisibleBarsSection, {
    dataLength: uiniqueKeysData.length,
    onMouseLeave: function onMouseLeave() {
      toggleTooltip(false);
      setTooltipData(null);
    }
  }, React.useMemo(function () {
    return uiniqueKeysData.map(function (dataItem, index) {
      var tooltipKeys = findTooltipKeys(dataItem, config);
      var tooltipValues = tooltipKeys.reduce(function (acum, key) {
        var tooltipItemValues = {
          label: config[key].label,
          key: key,
          value: dataItem[key]
        };
        acum.push(tooltipItemValues);
        return acum;
      }, []);
      var valuesEachArray = valuesArrays.map(function (array) {
        return array.find(function (_, sliceIndex) {
          return sliceIndex === index;
        });
      }).map(function (val) {
        return Number(val);
      }).filter(function (val) {
        return val && val;
      });
      var maxPathValue = valuesEachArray.length ? Math.max.apply(Math, valuesEachArray) : 0;
      var children = Object.keys(dataItem).map(function (dataConfigKey) {
        return React.createElement(BasicInvisibleBar, {
          key: "inner_" + dataItem.dataItemUID + "_" + dataConfigKey,
          dataConfigKey: dataConfigKey,
          dataItemProp: dataItem[dataConfigKey],
          config: config,
          innerSum: maxPathValue,
          tooltip: tooltip,
          minYValue: minValue
        });
      });
      var tooltipData = {
        xAxisValue: xAxisValues[index],
        dataConfigKey: '',
        tooltipValues: tooltipValues,
        barIndex: index,
        barValue: maxPathValue
      };
      return React.createElement(ParentInvisibleBar$1, {
        key: dataItem.dataItemUID,
        max: maxPathValue,
        barsNum: uiniqueKeysData.length,
        maxYAxis: maxValue,
        minYAxis: minValue,
        setTooltipData: setTooltipData,
        toggleTooltip: toggleTooltip,
        tooltipData: tooltipData
      }, children);
    });
  }, [uiniqueKeysData, minValue, maxValue])), tooltip && tooltip.isVisible && tooltipData && buildTooltip(tooltipData, uiniqueKeysData.length, maxValue, minValue, tooltipIsOpen, tooltip, config));
};

var LineChart = function LineChart(_ref) {
  var data = _ref.data,
      config = _ref.config,
      yAxis = _ref.yAxis,
      xAxis = _ref.xAxis,
      tooltip = _ref.tooltip,
      height = _ref.height,
      resizeDependency = _ref.resizeDependency,
      _ref$flexure = _ref.flexure,
      flexure = _ref$flexure === void 0 ? 0 : _ref$flexure;

  var _React$useState = React.useState(0),
      SVGWidth = _React$useState[0],
      setSVGWidth = _React$useState[1];

  var _React$useState2 = React.useState(0),
      SVGHeight = _React$useState2[0],
      setSVGHeight = _React$useState2[1];

  var wrapperRef = React.useRef(null);
  var _xAxis$step = xAxis.step,
      xAxisStep = _xAxis$step === void 0 ? Math.round(data.length > 10 ? data.length / 4 : 1) : _xAxis$step,
      _xAxis$ticksNum = xAxis.ticksNum,
      xAxisTicksNum = _xAxis$ticksNum === void 0 ? data.length : _xAxis$ticksNum,
      xAxisKey = xAxis.key,
      xAxisGrid = xAxis.grid,
      emptyArea = xAxis.emptyArea;
  var uiniqueKeysData = fillDataRelativeToXAxis(data, xAxisTicksNum);
  var essentialWidthFactor = uiniqueKeysData.length / xAxisTicksNum;
  var cellsNumber = uiniqueKeysData.length;
  var xAxisValues = uiniqueKeysData.map(function (dataItem) {
    return dataItem[xAxisKey];
  });
  React.useLayoutEffect(function () {
    if (wrapperRef.current) {
      var _wrapperRef$current = wrapperRef.current,
          clientWidth = _wrapperRef$current.clientWidth,
          clientHeight = _wrapperRef$current.clientHeight;
      setSVGWidth(clientWidth * essentialWidthFactor);
      setSVGHeight(clientHeight);
    }
  }, resizeDependency);
  useResize(function () {
    if (wrapperRef.current) {
      setSVGWidth(wrapperRef.current.clientWidth * essentialWidthFactor);
    }
  });
  var dataSlices = buildDataSlices(uiniqueKeysData, config);
  var valuesArrays = Object.entries(dataSlices).map(function (item) {
    return item[1];
  });
  var arrayOfAllValues = valuesArrays.reduce(function (acum, item) {
    return [].concat(acum, item);
  }, []);
  var _yAxis$maxValue = yAxis.maxValue,
      yAxisMax = _yAxis$maxValue === void 0 ? Math.max.apply(Math, arrayOfAllValues) : _yAxis$maxValue,
      _yAxis$minValue = yAxis.minValue,
      yAxisMin = _yAxis$minValue === void 0 ? 0 : _yAxis$minValue,
      _yAxis$ticksNum = yAxis.ticksNum,
      yAxisTicksNum = _yAxis$ticksNum === void 0 ? 3 : _yAxis$ticksNum,
      yAxisGrid = yAxis.grid;
  var yAxisValues = getYAxisValues(yAxisTicksNum, yAxisMax, yAxisMin);
  var width = SVGWidth * (data.length / cellsNumber); // SVG Should cut the extra paths

  return React.createElement(ChartWrapper, {
    height: height && getDenotedHeight(height)
  }, buildYAxis(yAxis, yAxisValues), React.createElement(ChartWithXAxisWrapper, null, React.createElement(ChartVisualsWrapper, {
    ref: wrapperRef
  }, buildGrid(xAxisValues, xAxisGrid, yAxisValues, yAxisGrid), React.createElement(SVG, {
    style: {
      width: width + "px"
    }
  }, Object.entries(dataSlices).map(function (dataSlice) {
    var d = buildPathD(dataSlice[0], dataSlice[1], config, SVGHeight, SVGWidth, cellsNumber, yAxisMax, yAxisMin, flexure);
    return buildPath(dataSlice[0], config, d);
  })), emptyArea && data.length / cellsNumber < 1 && React.createElement(EmptyAreaWrapper, null, emptyArea), React.createElement(LineChartBarsOverlay, {
    uiniqueKeysData: uiniqueKeysData,
    config: config,
    valuesArrays: valuesArrays,
    xAxisValues: xAxisValues,
    maxValue: yAxisMax,
    minValue: yAxisMin,
    tooltip: tooltip
  })), buildXAxis(xAxis, uiniqueKeysData, xAxisStep, true)));
};

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var constants = {
  chartHeight: '300px',
  defaultColor: '#757575',
  emptyBarColor: '#f0f0f0',
  defaultBargroupColor: '#757575'
};

var _templateObject;

var getHeight = function getHeight(height) {
  return height ? typeof height === 'number' ? height + "px" : height : constants.chartHeight;
};

var ChartWrapper = /*#__PURE__*/styled.section(_templateObject || (_templateObject = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  ", "\n  width: 100%;\n  box-sizing: border-box;\n  padding: 8px 8px 48px 8px;\n  position: relative;\n"])), function (_ref) {
  var height = _ref.height;
  return "\n    height: " + getHeight(height) + ";\n  ";
});

var _templateObject$1;
var ChartVisualsWrapper = /*#__PURE__*/styled.section(_templateObject$1 || (_templateObject$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  width: 100%;\n  height: 100%;\n  position: relative;\n"])));

var _templateObject$2;
var ChartWithXAxisWrapper = /*#__PURE__*/styled.section(_templateObject$2 || (_templateObject$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: block;\n  flex-wrap: wrap;\n  align-content: flex-start;\n  width: 100%;\n"])));

var _templateObject$3;
var BarChartBarsWrapper = /*#__PURE__*/styled.div(_templateObject$3 || (_templateObject$3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  width: 100%;\n"])));

var _templateObject$4;
var Bar = /*#__PURE__*/styled.div(_templateObject$4 || (_templateObject$4 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  background: ", ";\n"])), constants.defaultColor);

var _templateObject$5;
var BarGroup = /*#__PURE__*/styled.div(_templateObject$5 || (_templateObject$5 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  align-self: flex-end;\n  background: ", ";\n"])), constants.defaultBargroupColor);

var _templateObject$6;
var InvisibleBarGroup = /*#__PURE__*/styled.div(_templateObject$6 || (_templateObject$6 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  flex-shrink: 0;\n  position: relative;\n  width: 100%;\n"])));

var _templateObject$7;
var InvisibleBarsSection = /*#__PURE__*/styled.div(_templateObject$7 || (_templateObject$7 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  height: 100%;\n  display: flex;\n  flex-wrap: wrap;\n  align-items: flex-end;\n  position: absolute;\n  z-index: 1;\n  ", "\n"])), function (_ref) {
  var dataLength = _ref.dataLength;
  return "\n    width: calc(100% + " + 100 / (dataLength - 1) + "%);\n    margin-left: calc(" + -(100 + 100 / (dataLength - 1)) / dataLength / 2 + "%);\n  ";
});

var _templateObject$8;
var HintPoint = /*#__PURE__*/styled.div(_templateObject$8 || (_templateObject$8 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 9px;\n  height: 9px;\n  border-radius: 50%;\n  background: #303030;\n"])));

var _templateObject$9;
var InvisibleBar = /*#__PURE__*/styled.div(_templateObject$9 || (_templateObject$9 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  position: absolute;\n  width: 100%;\n  bottom: 0;\n  ", " {\n    opacity: 0;\n    position: absolute;\n    left: 50%;\n    top: 0;\n    transform: translateX(-50%) translateY(-50%);\n    transition: 0.1s all linear;\n  }\n"])), HintPoint);

var _templateObject$a;
var InvisibleBarGroupWrapper = /*#__PURE__*/styled.div(_templateObject$a || (_templateObject$a = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  height: 100%;\n  align-items: flex-end;\n  position: relative;\n  ", "\n  ", "\n\n", "\n  &:hover {\n    ", " {\n      ", " {\n        opacity: 1;\n      }\n    }\n  }\n"])), function (_ref) {
  var width = _ref.width;
  return "\n    width: " + width + ";\n  ";
}, function (_ref2) {
  var withSelection = _ref2.withSelection,
      isSelecting = _ref2.isSelecting,
      selected = _ref2.selected;
  return withSelection && isSelecting && "\n    opacity: " + (selected ? 1 : 0.8) + ";\n    transition: .1s opacity ease-in-out;\n    background:  " + (selected ? 'rgba(0, 0, 0, 0.05)' : 'transparent') + ";\n  ";
}, function (_ref3) {
  var selectedByInterval = _ref3.selectedByInterval,
      isSelecting = _ref3.isSelecting,
      selectionHighlighter = _ref3.selectionHighlighter;
  return selectedByInterval && !isSelecting && "\n     background: " + (selectionHighlighter || 'rgba(0, 0, 0, 0.1)') + ";\n  ";
}, InvisibleBar, HintPoint);

var _templateObject$b;
var EmptyBar = /*#__PURE__*/styled.div(_templateObject$b || (_templateObject$b = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n"])));

var _templateObject$c;
var EmptyAreaWrapper = /*#__PURE__*/styled.section(_templateObject$c || (_templateObject$c = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 100%;\n"])));

var _templateObject$d;
var SVG = /*#__PURE__*/styled.svg(_templateObject$d || (_templateObject$d = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  max-width: 100%;\n  display: flex;\n  flex-shrink: 0;\n  position: relative;\n  overflow: hidden;\n"])));

var _templateObject$e;
var Path = /*#__PURE__*/styled.path(_templateObject$e || (_templateObject$e = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  stroke: #757575;\n  stroke-width: 2px;\n  fill: transparent;\n"])));

var _templateObject$f;
var XAxisItem = /*#__PURE__*/styled.div(_templateObject$f || (_templateObject$f = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  justify-content: center;\n  padding: 8px 0;\n  position: absolute;\n  white-space: nowrap;\n"])));

var _templateObject$g;
var XAxisBarWrapper = /*#__PURE__*/styled.div(_templateObject$g || (_templateObject$g = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 100%;\n  display: flex;\n  position: relative;\n"])));

var _templateObject$h;
var XAxisLineWrapper = /*#__PURE__*/styled.aside(_templateObject$h || (_templateObject$h = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 100%;\n  display: flex;\n  position: relative;\n  ", " {\n    transform: translateX(-50%);\n  }\n"])), XAxisItem);

var _templateObject$i;
var YAxisWrapper = /*#__PURE__*/styled.ul(_templateObject$i || (_templateObject$i = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  justify-content: space-between;\n  height: 100%;\n  margin: 0;\n  padding: 0;\n  list-style: none;\n"])));

var _templateObject$j;
var YAxisItem = /*#__PURE__*/styled.li(_templateObject$j || (_templateObject$j = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  margin: 0;\n  padding: 0 8px 0 0;\n  list-style: none;\n"])));

var _templateObject$k;
var XGrid = /*#__PURE__*/styled.div(_templateObject$k || (_templateObject$k = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  width: 100%;\n  height: 1px;\n  background: #e0e0e0;\n  pointer-events: none;\n  position: absolute;\n"])));

var _templateObject$l;
var YGrid = /*#__PURE__*/styled.div(_templateObject$l || (_templateObject$l = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  height: 100%;\n  width: 1px;\n  background: #e0e0e0;\n  pointer-events: none;\n  position: absolute;\n"])));

var _templateObject$m;
var TooltipWrapper = /*#__PURE__*/styled.div(_templateObject$m || (_templateObject$m = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-direction: column;\n  position: absolute;\n  height: auto;\n  background: #303030;\n  border-radius: 5px;\n  color: #fff;\n  padding: 8px;\n  font-size: 14px;\n  transition: 0.08s all linear;\n  min-width: 120px;\n  max-width: 220px;\n  pointer-events: none;\n  ", " {\n    margin-right: 4px;\n  }\n"])), HintPoint);

var _templateObject$n;
var TooltipListItem = /*#__PURE__*/styled.li(_templateObject$n || (_templateObject$n = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  list-style: none;\n  padding: 0;\n  margin: 0;\n"])));

var _templateObject$o;
var TooltipList = /*#__PURE__*/styled.ul(_templateObject$o || (_templateObject$o = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  list-style: none;\n  margin: 0;\n  padding: 0;\n"])));

var _templateObject$p;
var TooltipListItemTextContent = /*#__PURE__*/styled.div(_templateObject$p || (_templateObject$p = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n"])));

var _templateObject$q;
var TooltipValue = /*#__PURE__*/styled.span(_templateObject$q || (_templateObject$q = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  font-weight: bold;\n"])));

var _templateObject$r;
var TooltipLabel = /*#__PURE__*/styled.p(_templateObject$r || (_templateObject$r = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  margin: 0 4px 0 0;\n"])));

var _templateObject$s;
var TooltipXAxisValue = /*#__PURE__*/styled.p(_templateObject$s || (_templateObject$s = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  margin: 8px 0 0 0;\n  padding: 4px 0 0 0;\n  border-top: 1px solid;\n"])));

var _templateObject$t;
var TooltipParentItem = /*#__PURE__*/styled.div(_templateObject$t || (_templateObject$t = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  width: 100%;\n  justify-content: space-between;\n  align-items: center;\n  margin: 4px 0 8px;\n  ", ", ", " {\n    font-size: 18px;\n  }\n"])), TooltipValue, TooltipLabel);

exports.Bar = Bar;
exports.BarChart = BarChart;
exports.BarChartBarsWrapper = BarChartBarsWrapper;
exports.BarGroup = BarGroup;
exports.ChartVisualsWrapper = ChartVisualsWrapper;
exports.ChartWithXAxisWrapper = ChartWithXAxisWrapper;
exports.ChartWrapper = ChartWrapper;
exports.EmptyAreaWrapper = EmptyAreaWrapper;
exports.EmptyBar = EmptyBar;
exports.HintPoint = HintPoint;
exports.InvisibleBar = InvisibleBar;
exports.InvisibleBarGroup = InvisibleBarGroup;
exports.InvisibleBarGroupWrapper = InvisibleBarGroupWrapper;
exports.InvisibleBarsSection = InvisibleBarsSection;
exports.LineChart = LineChart;
exports.Path = Path;
exports.SVG = SVG;
exports.TooltipLabel = TooltipLabel;
exports.TooltipList = TooltipList;
exports.TooltipListItem = TooltipListItem;
exports.TooltipListItemTextContent = TooltipListItemTextContent;
exports.TooltipParentItem = TooltipParentItem;
exports.TooltipValue = TooltipValue;
exports.TooltipWrapper = TooltipWrapper;
exports.TooltipXAxisValue = TooltipXAxisValue;
exports.XAxisBarWrapper = XAxisBarWrapper;
exports.XAxisItem = XAxisItem;
exports.XAxisLineWrapper = XAxisLineWrapper;
exports.XGrid = XGrid;
exports.YAxisItem = YAxisItem;
exports.YAxisWrapper = YAxisWrapper;
exports.YGrid = YGrid;
//# sourceMappingURL=styled-chart.cjs.development.js.map
